from setuptools import setup

setup(name='rpa_olymp',
      version='0.0',
      description='Description bib',
      packages=['rpa_olymp'],
      author_email='dima.prytkov.dima@mail.ru',
      zip_safe=False)
